@@ -110,6 +110,8 @@ EXCLUDE_USAGE = {
     'python/samba/tests/krb5/test_min_domain_uid.py',
     'python/samba/tests/krb5/test_idmap_nss.py',
     'python/samba/tests/krb5/pac_align_tests.py',
+    'python/samba/tests/krb5/protected_users_tests.py',
+    'python/samba/tests/krb5/nt_hash_tests.py',
     'python/samba/tests/krb5/kpasswd_tests.py',
     'python/samba/tests/krb5/lockout_tests.py',
     'python/samba/tests/krb5/etype_tests.py',
